==> org-lsst-sal-camera-2.6.3-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Autochanger_Latches_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Autochanger_Latches_TrendingTelemetry extends CameraTelemetry {
  private final int filterId;

  private final String filterName;

  private final String filterPresenceStatus;

  private final boolean latchxminus_filterEngagedSensorsInError;

  private final boolean latchxminus_filterPresenceSensorValue;

  private final boolean latchxminus_inError;

  private final boolean latchxminus_lockSensorValue;

  private final boolean latchxminus_lockSensorsInError;

  private final String latchxminus_lockStatus;

  private final boolean latchxminus_unlockSensorValue;

  private final boolean latchxminus_unlockSensorsInError;

  private final boolean latchxplus_filterEngagedSensorsInError;

  private final boolean latchxplus_filterPresenceSensorValue;

  private final boolean latchxplus_inError;

  private final boolean latchxplus_lockSensorValue;

  private final boolean latchxplus_lockSensorsInError;

  private final String latchxplus_lockStatus;

  private final boolean latchxplus_unlockSensorValue;

  private final boolean latchxplus_unlockSensorsInError;

  private final String lockStatus;

  public Fcs_Autochanger_Latches_TrendingTelemetry(int filterId, String filterName,
      String filterPresenceStatus, boolean latchxminus_filterEngagedSensorsInError,
      boolean latchxminus_filterPresenceSensorValue, boolean latchxminus_inError,
      boolean latchxminus_lockSensorValue, boolean latchxminus_lockSensorsInError,
      String latchxminus_lockStatus, boolean latchxminus_unlockSensorValue,
      boolean latchxminus_unlockSensorsInError, boolean latchxplus_filterEngagedSensorsInError,
      boolean latchxplus_filterPresenceSensorValue, boolean latchxplus_inError,
      boolean latchxplus_lockSensorValue, boolean latchxplus_lockSensorsInError,
      String latchxplus_lockStatus, boolean latchxplus_unlockSensorValue,
      boolean latchxplus_unlockSensorsInError, String lockStatus) {
    this.filterId = filterId;
    this.filterName = filterName;
    this.filterPresenceStatus = filterPresenceStatus;
    this.latchxminus_filterEngagedSensorsInError = latchxminus_filterEngagedSensorsInError;
    this.latchxminus_filterPresenceSensorValue = latchxminus_filterPresenceSensorValue;
    this.latchxminus_inError = latchxminus_inError;
    this.latchxminus_lockSensorValue = latchxminus_lockSensorValue;
    this.latchxminus_lockSensorsInError = latchxminus_lockSensorsInError;
    this.latchxminus_lockStatus = latchxminus_lockStatus;
    this.latchxminus_unlockSensorValue = latchxminus_unlockSensorValue;
    this.latchxminus_unlockSensorsInError = latchxminus_unlockSensorsInError;
    this.latchxplus_filterEngagedSensorsInError = latchxplus_filterEngagedSensorsInError;
    this.latchxplus_filterPresenceSensorValue = latchxplus_filterPresenceSensorValue;
    this.latchxplus_inError = latchxplus_inError;
    this.latchxplus_lockSensorValue = latchxplus_lockSensorValue;
    this.latchxplus_lockSensorsInError = latchxplus_lockSensorsInError;
    this.latchxplus_lockStatus = latchxplus_lockStatus;
    this.latchxplus_unlockSensorValue = latchxplus_unlockSensorValue;
    this.latchxplus_unlockSensorsInError = latchxplus_unlockSensorsInError;
    this.lockStatus = lockStatus;
  }

  public int getFilterId() {
    return filterId;
  }

  public String getFilterName() {
    return filterName;
  }

  public String getFilterPresenceStatus() {
    return filterPresenceStatus;
  }

  public boolean isLatchxminus_filterEngagedSensorsInError() {
    return latchxminus_filterEngagedSensorsInError;
  }

  public boolean isLatchxminus_filterPresenceSensorValue() {
    return latchxminus_filterPresenceSensorValue;
  }

  public boolean isLatchxminus_inError() {
    return latchxminus_inError;
  }

  public boolean isLatchxminus_lockSensorValue() {
    return latchxminus_lockSensorValue;
  }

  public boolean isLatchxminus_lockSensorsInError() {
    return latchxminus_lockSensorsInError;
  }

  public String getLatchxminus_lockStatus() {
    return latchxminus_lockStatus;
  }

  public boolean isLatchxminus_unlockSensorValue() {
    return latchxminus_unlockSensorValue;
  }

  public boolean isLatchxminus_unlockSensorsInError() {
    return latchxminus_unlockSensorsInError;
  }

  public boolean isLatchxplus_filterEngagedSensorsInError() {
    return latchxplus_filterEngagedSensorsInError;
  }

  public boolean isLatchxplus_filterPresenceSensorValue() {
    return latchxplus_filterPresenceSensorValue;
  }

  public boolean isLatchxplus_inError() {
    return latchxplus_inError;
  }

  public boolean isLatchxplus_lockSensorValue() {
    return latchxplus_lockSensorValue;
  }

  public boolean isLatchxplus_lockSensorsInError() {
    return latchxplus_lockSensorsInError;
  }

  public String getLatchxplus_lockStatus() {
    return latchxplus_lockStatus;
  }

  public boolean isLatchxplus_unlockSensorValue() {
    return latchxplus_unlockSensorValue;
  }

  public boolean isLatchxplus_unlockSensorsInError() {
    return latchxplus_unlockSensorsInError;
  }

  public String getLockStatus() {
    return lockStatus;
  }

  @Override
  public String toString() {
    return "Fcs_Autochanger_Latches_TrendingTelemetry{" + "filterId=" + filterId +
        ", filterName=" + filterName +", filterPresenceStatus=" + filterPresenceStatus +
        ", latchxminus_filterEngagedSensorsInError=" + latchxminus_filterEngagedSensorsInError +
        ", latchxminus_filterPresenceSensorValue=" + latchxminus_filterPresenceSensorValue +
        ", latchxminus_inError=" + latchxminus_inError +
        ", latchxminus_lockSensorValue=" + latchxminus_lockSensorValue +
        ", latchxminus_lockSensorsInError=" + latchxminus_lockSensorsInError +
        ", latchxminus_lockStatus=" + latchxminus_lockStatus +
        ", latchxminus_unlockSensorValue=" + latchxminus_unlockSensorValue +
        ", latchxminus_unlockSensorsInError=" + latchxminus_unlockSensorsInError +
        ", latchxplus_filterEngagedSensorsInError=" + latchxplus_filterEngagedSensorsInError +
        ", latchxplus_filterPresenceSensorValue=" + latchxplus_filterPresenceSensorValue +
        ", latchxplus_inError=" + latchxplus_inError +
        ", latchxplus_lockSensorValue=" + latchxplus_lockSensorValue +
        ", latchxplus_lockSensorsInError=" + latchxplus_lockSensorsInError +
        ", latchxplus_lockStatus=" + latchxplus_lockStatus +
        ", latchxplus_unlockSensorValue=" + latchxplus_unlockSensorValue +
        ", latchxplus_unlockSensorsInError=" + latchxplus_unlockSensorsInError +
        ", lockStatus=" + lockStatus +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int filterId;

    private String filterName;

    private String filterPresenceStatus;

    private boolean latchxminus_filterEngagedSensorsInError;

    private boolean latchxminus_filterPresenceSensorValue;

    private boolean latchxminus_inError;

    private boolean latchxminus_lockSensorValue;

    private boolean latchxminus_lockSensorsInError;

    private String latchxminus_lockStatus;

    private boolean latchxminus_unlockSensorValue;

    private boolean latchxminus_unlockSensorsInError;

    private boolean latchxplus_filterEngagedSensorsInError;

    private boolean latchxplus_filterPresenceSensorValue;

    private boolean latchxplus_inError;

    private boolean latchxplus_lockSensorValue;

    private boolean latchxplus_lockSensorsInError;

    private String latchxplus_lockStatus;

    private boolean latchxplus_unlockSensorValue;

    private boolean latchxplus_unlockSensorsInError;

    private String lockStatus;

    private Builder() {
    }

    public Builder filterId(int filterId) {
      this.filterId = filterId;
      return this;
    }

    public Builder filterName(String filterName) {
      this.filterName = filterName;
      return this;
    }

    public Builder filterPresenceStatus(String filterPresenceStatus) {
      this.filterPresenceStatus = filterPresenceStatus;
      return this;
    }

    public Builder latchxminus_filterEngagedSensorsInError(
        boolean latchxminus_filterEngagedSensorsInError) {
      this.latchxminus_filterEngagedSensorsInError = latchxminus_filterEngagedSensorsInError;
      return this;
    }

    public Builder latchxminus_filterPresenceSensorValue(
        boolean latchxminus_filterPresenceSensorValue) {
      this.latchxminus_filterPresenceSensorValue = latchxminus_filterPresenceSensorValue;
      return this;
    }

    public Builder latchxminus_inError(boolean latchxminus_inError) {
      this.latchxminus_inError = latchxminus_inError;
      return this;
    }

    public Builder latchxminus_lockSensorValue(boolean latchxminus_lockSensorValue) {
      this.latchxminus_lockSensorValue = latchxminus_lockSensorValue;
      return this;
    }

    public Builder latchxminus_lockSensorsInError(boolean latchxminus_lockSensorsInError) {
      this.latchxminus_lockSensorsInError = latchxminus_lockSensorsInError;
      return this;
    }

    public Builder latchxminus_lockStatus(String latchxminus_lockStatus) {
      this.latchxminus_lockStatus = latchxminus_lockStatus;
      return this;
    }

    public Builder latchxminus_unlockSensorValue(boolean latchxminus_unlockSensorValue) {
      this.latchxminus_unlockSensorValue = latchxminus_unlockSensorValue;
      return this;
    }

    public Builder latchxminus_unlockSensorsInError(boolean latchxminus_unlockSensorsInError) {
      this.latchxminus_unlockSensorsInError = latchxminus_unlockSensorsInError;
      return this;
    }

    public Builder latchxplus_filterEngagedSensorsInError(
        boolean latchxplus_filterEngagedSensorsInError) {
      this.latchxplus_filterEngagedSensorsInError = latchxplus_filterEngagedSensorsInError;
      return this;
    }

    public Builder latchxplus_filterPresenceSensorValue(
        boolean latchxplus_filterPresenceSensorValue) {
      this.latchxplus_filterPresenceSensorValue = latchxplus_filterPresenceSensorValue;
      return this;
    }

    public Builder latchxplus_inError(boolean latchxplus_inError) {
      this.latchxplus_inError = latchxplus_inError;
      return this;
    }

    public Builder latchxplus_lockSensorValue(boolean latchxplus_lockSensorValue) {
      this.latchxplus_lockSensorValue = latchxplus_lockSensorValue;
      return this;
    }

    public Builder latchxplus_lockSensorsInError(boolean latchxplus_lockSensorsInError) {
      this.latchxplus_lockSensorsInError = latchxplus_lockSensorsInError;
      return this;
    }

    public Builder latchxplus_lockStatus(String latchxplus_lockStatus) {
      this.latchxplus_lockStatus = latchxplus_lockStatus;
      return this;
    }

    public Builder latchxplus_unlockSensorValue(boolean latchxplus_unlockSensorValue) {
      this.latchxplus_unlockSensorValue = latchxplus_unlockSensorValue;
      return this;
    }

    public Builder latchxplus_unlockSensorsInError(boolean latchxplus_unlockSensorsInError) {
      this.latchxplus_unlockSensorsInError = latchxplus_unlockSensorsInError;
      return this;
    }

    public Builder lockStatus(String lockStatus) {
      this.lockStatus = lockStatus;
      return this;
    }

    public Fcs_Autochanger_Latches_TrendingTelemetry build() {
      return new Fcs_Autochanger_Latches_TrendingTelemetry(filterId, filterName, filterPresenceStatus, latchxminus_filterEngagedSensorsInError, latchxminus_filterPresenceSensorValue, latchxminus_inError, latchxminus_lockSensorValue, latchxminus_lockSensorsInError, latchxminus_lockStatus, latchxminus_unlockSensorValue, latchxminus_unlockSensorsInError, latchxplus_filterEngagedSensorsInError, latchxplus_filterPresenceSensorValue, latchxplus_inError, latchxplus_lockSensorValue, latchxplus_lockSensorsInError, latchxplus_lockStatus, latchxplus_unlockSensorValue, latchxplus_unlockSensorsInError, lockStatus);
    }
  }
}

==> org-lsst-sal-camera-3.0.1-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Autochanger_Latches_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Autochanger_Latches_TrendingTelemetry extends CameraTelemetry {
  private final int filterId;

  private final String filterName;

  private final String filterPresenceStatus;

  private final boolean latchxminus_filterEngagedSensorsInError;

  private final boolean latchxminus_filterPresenceSensorOn;

  private final boolean latchxminus_inError;

  private final boolean latchxminus_lockSensorOn;

  private final boolean latchxminus_lockSensorsInError;

  private final String latchxminus_lockStatus;

  private final boolean latchxminus_unlockSensorOn;

  private final boolean latchxminus_unlockSensorsInError;

  private final boolean latchxplus_filterEngagedSensorsInError;

  private final boolean latchxplus_filterPresenceSensorOn;

  private final boolean latchxplus_inError;

  private final boolean latchxplus_lockSensorOn;

  private final boolean latchxplus_lockSensorsInError;

  private final String latchxplus_lockStatus;

  private final boolean latchxplus_unlockSensorOn;

  private final boolean latchxplus_unlockSensorsInError;

  private final String lockStatus;

  public Fcs_Autochanger_Latches_TrendingTelemetry(int filterId, String filterName,
      String filterPresenceStatus, boolean latchxminus_filterEngagedSensorsInError,
      boolean latchxminus_filterPresenceSensorOn, boolean latchxminus_inError,
      boolean latchxminus_lockSensorOn, boolean latchxminus_lockSensorsInError,
      String latchxminus_lockStatus, boolean latchxminus_unlockSensorOn,
      boolean latchxminus_unlockSensorsInError, boolean latchxplus_filterEngagedSensorsInError,
      boolean latchxplus_filterPresenceSensorOn, boolean latchxplus_inError,
      boolean latchxplus_lockSensorOn, boolean latchxplus_lockSensorsInError,
      String latchxplus_lockStatus, boolean latchxplus_unlockSensorOn,
      boolean latchxplus_unlockSensorsInError, String lockStatus) {
    this.filterId = filterId;
    this.filterName = filterName;
    this.filterPresenceStatus = filterPresenceStatus;
    this.latchxminus_filterEngagedSensorsInError = latchxminus_filterEngagedSensorsInError;
    this.latchxminus_filterPresenceSensorOn = latchxminus_filterPresenceSensorOn;
    this.latchxminus_inError = latchxminus_inError;
    this.latchxminus_lockSensorOn = latchxminus_lockSensorOn;
    this.latchxminus_lockSensorsInError = latchxminus_lockSensorsInError;
    this.latchxminus_lockStatus = latchxminus_lockStatus;
    this.latchxminus_unlockSensorOn = latchxminus_unlockSensorOn;
    this.latchxminus_unlockSensorsInError = latchxminus_unlockSensorsInError;
    this.latchxplus_filterEngagedSensorsInError = latchxplus_filterEngagedSensorsInError;
    this.latchxplus_filterPresenceSensorOn = latchxplus_filterPresenceSensorOn;
    this.latchxplus_inError = latchxplus_inError;
    this.latchxplus_lockSensorOn = latchxplus_lockSensorOn;
    this.latchxplus_lockSensorsInError = latchxplus_lockSensorsInError;
    this.latchxplus_lockStatus = latchxplus_lockStatus;
    this.latchxplus_unlockSensorOn = latchxplus_unlockSensorOn;
    this.latchxplus_unlockSensorsInError = latchxplus_unlockSensorsInError;
    this.lockStatus = lockStatus;
  }

  public int getFilterId() {
    return filterId;
  }

  public String getFilterName() {
    return filterName;
  }

  public String getFilterPresenceStatus() {
    return filterPresenceStatus;
  }

  public boolean isLatchxminus_filterEngagedSensorsInError() {
    return latchxminus_filterEngagedSensorsInError;
  }

  public boolean isLatchxminus_filterPresenceSensorOn() {
    return latchxminus_filterPresenceSensorOn;
  }

  public boolean isLatchxminus_inError() {
    return latchxminus_inError;
  }

  public boolean isLatchxminus_lockSensorOn() {
    return latchxminus_lockSensorOn;
  }

  public boolean isLatchxminus_lockSensorsInError() {
    return latchxminus_lockSensorsInError;
  }

  public String getLatchxminus_lockStatus() {
    return latchxminus_lockStatus;
  }

  public boolean isLatchxminus_unlockSensorOn() {
    return latchxminus_unlockSensorOn;
  }

  public boolean isLatchxminus_unlockSensorsInError() {
    return latchxminus_unlockSensorsInError;
  }

  public boolean isLatchxplus_filterEngagedSensorsInError() {
    return latchxplus_filterEngagedSensorsInError;
  }

  public boolean isLatchxplus_filterPresenceSensorOn() {
    return latchxplus_filterPresenceSensorOn;
  }

  public boolean isLatchxplus_inError() {
    return latchxplus_inError;
  }

  public boolean isLatchxplus_lockSensorOn() {
    return latchxplus_lockSensorOn;
  }

  public boolean isLatchxplus_lockSensorsInError() {
    return latchxplus_lockSensorsInError;
  }

  public String getLatchxplus_lockStatus() {
    return latchxplus_lockStatus;
  }

  public boolean isLatchxplus_unlockSensorOn() {
    return latchxplus_unlockSensorOn;
  }

  public boolean isLatchxplus_unlockSensorsInError() {
    return latchxplus_unlockSensorsInError;
  }

  public String getLockStatus() {
    return lockStatus;
  }

  @Override
  public String toString() {
    return "Fcs_Autochanger_Latches_TrendingTelemetry{" + "filterId=" + filterId +
        ", filterName=" + filterName +", filterPresenceStatus=" + filterPresenceStatus +
        ", latchxminus_filterEngagedSensorsInError=" + latchxminus_filterEngagedSensorsInError +
        ", latchxminus_filterPresenceSensorOn=" + latchxminus_filterPresenceSensorOn +
        ", latchxminus_inError=" + latchxminus_inError +
        ", latchxminus_lockSensorOn=" + latchxminus_lockSensorOn +
        ", latchxminus_lockSensorsInError=" + latchxminus_lockSensorsInError +
        ", latchxminus_lockStatus=" + latchxminus_lockStatus +
        ", latchxminus_unlockSensorOn=" + latchxminus_unlockSensorOn +
        ", latchxminus_unlockSensorsInError=" + latchxminus_unlockSensorsInError +
        ", latchxplus_filterEngagedSensorsInError=" + latchxplus_filterEngagedSensorsInError +
        ", latchxplus_filterPresenceSensorOn=" + latchxplus_filterPresenceSensorOn +
        ", latchxplus_inError=" + latchxplus_inError +
        ", latchxplus_lockSensorOn=" + latchxplus_lockSensorOn +
        ", latchxplus_lockSensorsInError=" + latchxplus_lockSensorsInError +
        ", latchxplus_lockStatus=" + latchxplus_lockStatus +
        ", latchxplus_unlockSensorOn=" + latchxplus_unlockSensorOn +
        ", latchxplus_unlockSensorsInError=" + latchxplus_unlockSensorsInError +
        ", lockStatus=" + lockStatus +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int filterId;

    private String filterName;

    private String filterPresenceStatus;

    private boolean latchxminus_filterEngagedSensorsInError;

    private boolean latchxminus_filterPresenceSensorOn;

    private boolean latchxminus_inError;

    private boolean latchxminus_lockSensorOn;

    private boolean latchxminus_lockSensorsInError;

    private String latchxminus_lockStatus;

    private boolean latchxminus_unlockSensorOn;

    private boolean latchxminus_unlockSensorsInError;

    private boolean latchxplus_filterEngagedSensorsInError;

    private boolean latchxplus_filterPresenceSensorOn;

    private boolean latchxplus_inError;

    private boolean latchxplus_lockSensorOn;

    private boolean latchxplus_lockSensorsInError;

    private String latchxplus_lockStatus;

    private boolean latchxplus_unlockSensorOn;

    private boolean latchxplus_unlockSensorsInError;

    private String lockStatus;

    private Builder() {
    }

    public Builder filterId(int filterId) {
      this.filterId = filterId;
      return this;
    }

    public Builder filterName(String filterName) {
      this.filterName = filterName;
      return this;
    }

    public Builder filterPresenceStatus(String filterPresenceStatus) {
      this.filterPresenceStatus = filterPresenceStatus;
      return this;
    }

    public Builder latchxminus_filterEngagedSensorsInError(
        boolean latchxminus_filterEngagedSensorsInError) {
      this.latchxminus_filterEngagedSensorsInError = latchxminus_filterEngagedSensorsInError;
      return this;
    }

    public Builder latchxminus_filterPresenceSensorOn(boolean latchxminus_filterPresenceSensorOn) {
      this.latchxminus_filterPresenceSensorOn = latchxminus_filterPresenceSensorOn;
      return this;
    }

    public Builder latchxminus_inError(boolean latchxminus_inError) {
      this.latchxminus_inError = latchxminus_inError;
      return this;
    }

    public Builder latchxminus_lockSensorOn(boolean latchxminus_lockSensorOn) {
      this.latchxminus_lockSensorOn = latchxminus_lockSensorOn;
      return this;
    }

    public Builder latchxminus_lockSensorsInError(boolean latchxminus_lockSensorsInError) {
      this.latchxminus_lockSensorsInError = latchxminus_lockSensorsInError;
      return this;
    }

    public Builder latchxminus_lockStatus(String latchxminus_lockStatus) {
      this.latchxminus_lockStatus = latchxminus_lockStatus;
      return this;
    }

    public Builder latchxminus_unlockSensorOn(boolean latchxminus_unlockSensorOn) {
      this.latchxminus_unlockSensorOn = latchxminus_unlockSensorOn;
      return this;
    }

    public Builder latchxminus_unlockSensorsInError(boolean latchxminus_unlockSensorsInError) {
      this.latchxminus_unlockSensorsInError = latchxminus_unlockSensorsInError;
      return this;
    }

    public Builder latchxplus_filterEngagedSensorsInError(
        boolean latchxplus_filterEngagedSensorsInError) {
      this.latchxplus_filterEngagedSensorsInError = latchxplus_filterEngagedSensorsInError;
      return this;
    }

    public Builder latchxplus_filterPresenceSensorOn(boolean latchxplus_filterPresenceSensorOn) {
      this.latchxplus_filterPresenceSensorOn = latchxplus_filterPresenceSensorOn;
      return this;
    }

    public Builder latchxplus_inError(boolean latchxplus_inError) {
      this.latchxplus_inError = latchxplus_inError;
      return this;
    }

    public Builder latchxplus_lockSensorOn(boolean latchxplus_lockSensorOn) {
      this.latchxplus_lockSensorOn = latchxplus_lockSensorOn;
      return this;
    }

    public Builder latchxplus_lockSensorsInError(boolean latchxplus_lockSensorsInError) {
      this.latchxplus_lockSensorsInError = latchxplus_lockSensorsInError;
      return this;
    }

    public Builder latchxplus_lockStatus(String latchxplus_lockStatus) {
      this.latchxplus_lockStatus = latchxplus_lockStatus;
      return this;
    }

    public Builder latchxplus_unlockSensorOn(boolean latchxplus_unlockSensorOn) {
      this.latchxplus_unlockSensorOn = latchxplus_unlockSensorOn;
      return this;
    }

    public Builder latchxplus_unlockSensorsInError(boolean latchxplus_unlockSensorsInError) {
      this.latchxplus_unlockSensorsInError = latchxplus_unlockSensorsInError;
      return this;
    }

    public Builder lockStatus(String lockStatus) {
      this.lockStatus = lockStatus;
      return this;
    }

    public Fcs_Autochanger_Latches_TrendingTelemetry build() {
      return new Fcs_Autochanger_Latches_TrendingTelemetry(filterId, filterName, filterPresenceStatus, latchxminus_filterEngagedSensorsInError, latchxminus_filterPresenceSensorOn, latchxminus_inError, latchxminus_lockSensorOn, latchxminus_lockSensorsInError, latchxminus_lockStatus, latchxminus_unlockSensorOn, latchxminus_unlockSensorsInError, latchxplus_filterEngagedSensorsInError, latchxplus_filterPresenceSensorOn, latchxplus_inError, latchxplus_lockSensorOn, latchxplus_lockSensorsInError, latchxplus_lockStatus, latchxplus_unlockSensorOn, latchxplus_unlockSensorsInError, lockStatus);
    }
  }
}
